diff --git a/auth/interface.go b/auth/interface.go
index 52b1d9dd3febeb03b3f792b570e977ddd2341fc1..ac0b1c4b89e18adf9f8ecd90952aee723ad2aaff 100644
--- a/auth/interface.go
+++ b/auth/interface.go
@@ -57,7 +57,7 @@ type State interface {
 	// This will not be useful if either side has ratcheted
 	ReplayConfirm(partner *id.ID) (id.Round, error)
 
-	// ReplayRequests will iterate through all pending contact requests and replay
-	// them on the callbacks.
-	ReplayRequests()
+	// CallReceivedRequests will iterate through all pending contact requests
+	// and replay them on the callbacks.
+	CallReceivedRequests()
 }
diff --git a/auth/state.go b/auth/state.go
index 9c78cc9554924f8a2b212978c8c33d3aa18f0c95..ef311d23a9711a89b99ae9ec7c337ea26a28d19a 100644
--- a/auth/state.go
+++ b/auth/state.go
@@ -112,9 +112,9 @@ func NewStateLegacy(kv *versioned.KV, net cmix.Client, e2e e2e.Handler,
 	return s, nil
 }
 
 // ReplayRequests will iterate through all pending contact requests and replay
 // them on the callbacks.
-func (s *state) ReplayRequests() {
+func (s *state) CallReceivedRequests() {
 	rrList := s.store.GetAllReceivedRequests()
 	for i := range rrList {
 		rr := rrList[i]
@@ -112,9 +112,9 @@ func NewStateLegacy(kv *versioned.KV, net cmix.Client, e2e e2e.Handler,
 }
 
-// ReplayRequests will iterate through all pending contact requests and replay
+// CallReceivedRequests will iterate through all pending contact requests and replay
 // them on the callbacks.